@@ -2,13 +2,12 @@ import json
 import typing
 
 import packaging.version as version
-from hypothesis import given, strategies as st
+from hypothesis import given, strategies as st, assume
 import pydantic
 import pytest
 from typing_extensions import Annotated
 
 from hrefs import Href, BaseReferrableModel, PrimaryKey
-from util import hrefs
 
 
 def _pydantic_does_not_support_field_in_modify_schema():
@@ -34,10 +33,7 @@ class Owner(pydantic.BaseModel):
     pets: typing.List[Href[Pet]]
 
 
-pet_hrefs = hrefs(Pet, st.integers())
-
-
-@given(pet_hrefs)
+@given(st.from_type(Href[Pet]))
 def test_parse_href(href):
     assert pydantic.parse_obj_as(Href[Pet], href) is href
 
@@ -73,14 +69,14 @@ def test_parse_href_without_parameter_fails():
         pydantic.parse_obj_as(Href, 123)
 
 
-@given(st.builds(Owner, pets=st.lists(pet_hrefs)))
+@given(st.builds(Owner))
 def test_json_encode(owner):
     owner_json = json.loads(owner.json())
     assert owner_json["pets"] == [pet.url for pet in owner.pets]
 
 
 @given(st.integers())
-def test_primary_key_annotation(my_id):
+def test_primary_key_annotation(my_id) -> None:
     class MyModel(BaseReferrableModel):
         my_id: Annotated[int, PrimaryKey]
 
@@ -95,7 +91,7 @@ def test_primary_key_annotation(my_id):
     assert MyModel(my_id=my_id).get_key() == my_id
 
 
-def test_multiple_primary_key_annotations_fails():
+def test_multiple_primary_key_annotations_fails() -> None:
     with pytest.raises(TypeError):
 
         class MyModel(BaseReferrableModel):
@@ -110,7 +106,7 @@ def test_multiple_primary_key_annotations_fails():
                 ...
 
 
-def test_href_forward_reference():
+def test_href_forward_reference() -> None:
     class MyModel(BaseReferrableModel):
         id: int
         self: Href["MyModel"]
@@ -121,7 +117,7 @@ def test_href_forward_reference():
             return values
 
         @staticmethod
-        def key_to_url(key: int) -> None:
+        def key_to_url(key: int):
             return f"/{key}"
 
         @staticmethod
@@ -134,7 +130,7 @@ def test_href_forward_reference():
 
 
 @given(st.integers(), st.floats())
-def test_derived_model_inherits_referrable_properties(key, purr_frequency):
+def test_derived_model_inherits_referrable_properties(key, purr_frequency) -> None:
     class Cat(Pet):
         purr_frequency: float
 
@@ -148,7 +144,7 @@ def test_derived_model_inherits_referrable_properties(key, purr_frequency):
     _pydantic_does_not_support_field_in_modify_schema(),
     reason="pydantic does not support field argument in __modify_schema__",
 )
-def test_href_schema():
+def test_href_schema() -> None:
     owner_schema = Owner.schema()
     assert owner_schema["properties"]["pets"] == {
         "title": "Pets",
@@ -157,3 +153,33 @@ def test_href_schema():
             "type": "string",
         },
     }
+
+
+@given(st.from_type(Href[Pet]))
+def test_hash_of_equivalent_hrefs_matches(href):
+    other_href = Href(key=href.key, url=href.url)
+    assert hash(href) == hash(other_href)
+
+
+@given(st.from_type(Href[Pet]), st.from_type(Href[Pet]))
+def test_hash_of_different_hrefs_differs(href, other_href):
+    assume(href != other_href)
+    assert hash(href) != hash(other_href)
+
+
+@given(st.from_type(Href[Pet]))
+def test_hypothesis_plugin(href):
+    assert isinstance(href, Href)
+    assert href.url == Pet.key_to_url(href.key)
+
+
+@pytest.mark.filterwarnings("ignore::hypothesis.errors.NonInteractiveExampleWarning")
+def test_hypothesis_plugin_plain_href_fails():
+    with pytest.raises(ValueError):
+        st.from_type(Href).example()
+
+
+@pytest.mark.filterwarnings("ignore::hypothesis.errors.NonInteractiveExampleWarning")
+def test_hypothesis_plugin_href_to_non_referrable_type_fails():
+    with pytest.raises(ValueError):
+        st.from_type(Href[int]).example()
